@@ -159,6 +159,9 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     if df_raw.shape[0] == 0:
         print("Empty prompt response file : " + csv_path[0])
         quit()
+
+    if "Question_1_Answer_Unixtime" not in df_raw:
+        print("$$$$$$$$$$$$$$$$$$$$ {}".format(date_folder_path))
     df_raw = df_raw[columns_list]
 
     if "Reprompt2_Prompt_UnixTime " in df_raw.columns:
